from setuptools import setup

setup(name='ftThanos',
version="0.0.70",
description="A client for 70 API",
author="Thanos 70",
author_email="thanos@70paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
